# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta
from django.utils.translation import ugettext as _
from django.http import HttpResponseRedirect
from project.view import FuncView
from project.fal.command import get_message
from root.modules.form import BaseForm
from ..modules.protocol import Protocol


def root(request):
    return HttpResponseRedirect('./appleshare')


class Form(BaseForm):
    def __init__(self, *args, **kwargs):
        from root.modules.form.fields.radio import RadioField
        super(Form, self).__init__(*args, **kwargs)

        self.fields["appleshare"] = RadioField(
                label=_(u'AppleShare Network'),
                initial=0,
                required=True,
                validators=[])


class View(FuncView):
    protocol = Protocol()
    views = ['apply']

    def view(self, request):
        form = Form(initial=self.protocol.get_appleshare_config())
        return {
            self.KEY_TEMPLATE: self.TEMPLATE,
            self.KEY_TEMPLATE_DIC: {'form': form}}

    def view_apply(self, request):
        with self.processing(constname="ERR_APPLE_NET_STATE_CHANGE") as p:
            form = Form(data=request.POST)
            rst = False
            p.break_if_state_change()

            if form.is_valid():
                if self.protocol.appleshare_set(data=form.cleaned_data):
                    self.set_message(get_message('MSG_APPLE_CHANGE', is_log=True))
                    rst = True
                else:
                    self.set_message(get_message('ERR_APPLE_CHANGE', is_log=True))
                p.result(rst)
        return {
            self.KEY_TEMPLATE: self.TEMPLATE,
            self.KEY_TEMPLATE_DIC: {'form': form}}


appleshare = View.as_view()
